#!/bin/bash

# Copyright(C) 2005, International Business Machines Corporation.  All
# Rights Reserved.

# Usage: ./run_share_tests.sh <server ip address>
#
# This script simulates what happens in ABAT, except it is run from
# the samba client machine rather than from an ABAT server (files
# are copied only to the samba server).  It is dependent on the 
# following:
#    1. Files:
#		config_[sles9/rhel4/rhel3]_test.pl
#		modify_samba_config.pl
#		share_tests_client.conf
#		share_tests_server.conf
#		start_print_server.pl
#		stop_print_server.pl
#		test_tools.pm
#		undo_config.pl
#    2. The server must be prepared to accept ssh commands.  Note that for
#       the standalone tests the client is also the server.  Set up ssh
#       in the following manner:
#          On the client (this machine):
#		ssh-keygen -t dsa (enter a passphrase when prompted)
#		ssh-agent /bin/bash
#		ssh-add (enter the passphrase when prompted)
#	    On the server:
#		scp <client>:/root/.ssh/id_dsa.pub /root/.ssh/authorized_keys
#		chmod 600 /root/.ssh/authorized_keys
#

# Save options
SERVER=$1
if [ ! $SERVER ]; then
    echo "Please enter the server ip address"
    exit 1
fi
LOGFILE="share.log"

# Must be root to run this script
USER=`whoami`
if [ $USER != "root" ]; then 
    echo "You are $USER--must be root to run this script";
    exit 1
fi

# Set up the required server configuration file
TESTCONF=share_tests_server.conf

# Create a working directory on the server
TESTDIR=$HOME/samba_testing
ssh $SERVER "mkdir $TESTDIR"

# Copy the necessary files to the server
CURDIR=`pwd`
cd ..
chmod +x share/*.pl share/*.sh util/*.pl util/*.sh
tar -cf samba_testing.tar .
scp samba_testing.tar $SERVER:$TESTDIR/.
rm -f samba_testing.tar
ssh $SERVER "cd ${TESTDIR}; tar -xf samba_testing.tar"
cd $CURDIR

# Check if smbldap-tools needs to be installed
grep -i "BACKEND=ldapsam" $TESTCONF
if [ $? == 0 ]; then
    echo "Checking for smbldap tools on $SERVER"
    ssh $SERVER "cd $TESTDIR/util; ./install_smbldap_tools.sh"
fi

# Start the virtual printer
echo "Starting the virtual printer on $SERVER"
ssh $SERVER "cd ${TESTDIR}/util; ./start_print_server.pl -l ${LOGFILE}" &

# Set up the server 
echo "Running share_tests_server.pl -a start on $SERVER"
ssh $SERVER "cd ${TESTDIR}/share; ./share_tests_server.pl -a start -l ${LOGFILE}" &

# Run the client tests on the client
echo "Running share_tests_client.pl locally"
./share_tests_client.pl -a start -s ${SERVER} -l ${LOGFILE}

# Concatenate the log files
scp $SERVER:$TESTDIR/share/share.log temp.log
cat temp.log >> share.log
rm temp.log

# Undo the server configuration
echo "Running share_tests_server.pl -a stop on $SERVER"
ssh $SERVER "cd ${TESTDIR}/share; ./share_tests_server.pl -a stop -l ${LOGFILE}"

# Clean up the files on the server
ssh $SERVER "rm -rf ${TESTDIR}"

# Undo the client configuration
echo "Running share_tests_client.pl -a stop on localhost"
./share_tests_client.pl -a stop -l ${LOGFILE}

# Run the standalone tests
echo " " >> $LOGFILE
echo "===== START OF STANDALONE LOG =====" >> $LOGFILE
echo " " >> $LOGFILE
sleep 3

# Check if smbldap-tools needs to be installed
grep -i "BACKEND=ldapsam" $TESTCONF
if [ $? == 0 ]; then
    echo "Checking for smbldap tools on localhost"
    ../util/install_smbldap_tools.sh
fi
echo "Running share_tests_standalone.pl locally"
./share_tests_standalone.pl -l ${LOGFILE}

# End of script
exit 1
